@@ -91,7 +91,7 @@ use List::MoreUtils qw( uniq );
 use Readonly;
 use Text::ParseWords qw( parse_line );
 
-our $VERSION = version->new('1.6.0');
+our $VERSION = version->new('1.6.2');
 
 Readonly my $COMMA     => q{,};
 Readonly my $EMPTY_STR => q{};
@@ -270,7 +270,6 @@ opening the file in order to bind the field names in the first row.
 =cut
 
     my $self = shift;
-$DB::single = 1;
 
     if ( my @columns = $self->fetchrow_array ) {
         if ( my $filter = $self->header_filter ) {
@@ -1110,6 +1109,10 @@ fields.  Use a "false" argument to disable.
 
 Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>
 
+=head1 SOURCE
+
+http://github.com/kyclark/text-recordparser
+
 =head1 CREDITS
 
 Thanks to the following:
